searchNodes=[{"doc":"Elixir bindings to Vega-Lite . Vega-Lite offers a high-level grammar for composing interactive graphics, where every graphic is specified in a declarative fashion relying solely on JSON syntax. To learn more about Vega-Lite please refer to the documentation and explore numerous examples . This package offers a tiny layer of functionality that makes it easier to build a Vega-Lite graphics specification. Composing graphics We offers a light-weight pipeline API akin to the JSON specification. Translating existing Vega-Lite specifications to such specification should be very intuitive in most cases. Composing a basic Vega-Lite graphic usually consists of the following steps: alias VegaLite , as : Vl # Initialize the specification, optionally with some top-level properties Vl . new ( width : 400 , height : 400 ) # Specify data source for the graphic, see the data_from_* functions |&gt; Vl . data_from_values ( iteration : 1 .. 100 , score : 1 .. 100 ) # |&gt; Vl.data_from_values([%{iteration: 1, score: 1}, ...]) # |&gt; Vl.data_from_url(&quot;...&quot;) # Pick a visual mark for the graphic |&gt; Vl . mark ( :line ) # |&gt; Vl.mark(:point, tooltip: true) # Map data fields to visual properties of the mark, like position or shape |&gt; Vl . encode_field ( :x , &quot;iteration&quot; , type : :quantitative ) |&gt; Vl . encode_field ( :y , &quot;score&quot; , type : :quantitative ) # |&gt; Vl.encode(:color, &quot;country&quot;, type: :nominal) # |&gt; Vl.encode(:size, &quot;count&quot;, type: :quantitative) Then, you can compose multiple graphics using layers/2 , concat/3 , repeat/3 or facet/3 . Vl . new ( ) |&gt; Vl . data_from_url ( &quot;https://vega.github.io/editor/data/weather.csv&quot; ) |&gt; Vl . transform ( filter : &quot;datum.location == &#39;Seattle&#39;&quot; ) |&gt; Vl . concat ( [ Vl . new ( ) |&gt; Vl . mark ( :bar ) |&gt; Vl . encode_field ( :x , &quot;date&quot; , time_unit : :month , type : :ordinal ) |&gt; Vl . encode_field ( :y , &quot;precipitation&quot; , aggregate : :mean ) , Vl . new ( ) |&gt; Vl . mark ( :point ) |&gt; Vl . encode_field ( :x , &quot;temp_min&quot; , bin : true ) |&gt; Vl . encode_field ( :y , &quot;temp_max&quot; , bin : true ) |&gt; Vl . encode ( :size , aggregate : :count ) ] ) Additionally, you can use transform/2 to preprocess the data, param/3 for introducing interactivity and config/2 for global customization. Using JSON specification Alternatively you can parse a Vega-Lite JSON specification directly. This approach makes it easy to explore numerous examples available online. alias VegaLite , as : Vl Vl . from_json ( &quot;&quot;&quot; { &quot;data&quot;: { &quot;url&quot;: &quot;https://vega.github.io/editor/data/cars.json&quot; }, &quot;mark&quot;: &quot;point&quot;, &quot;encoding&quot;: { &quot;x&quot;: { &quot;field&quot;: &quot;Horsepower&quot;, &quot;type&quot;: &quot;quantitative&quot; }, &quot;y&quot;: { &quot;field&quot;: &quot;Miles_per_Gallon&quot;, &quot;type&quot;: &quot;quantitative&quot; } } } &quot;&quot;&quot; ) The result of VegaLite.from_json/1 function can then be passed through any other function to further customize the specification. In particular, it may be useful to parse a JSON specification and add your custom data with VegaLite.data_from_values/3 . Options Most VegaLite functions accept an optional list of options, which are converted directly as the specification properties. To provide a more Elixir-friendly experience, the options are automatically normalized, so you can use keyword lists and snake-case atom keys.","ref":"VegaLite.html","title":"VegaLite","type":"module"},{"doc":"Builds a concatenated multi-view specification from the given list of single view specifications. The concat type must be either :wrappable (default), :horizontal or :vertical . Examples Vl . new ( ) |&gt; Vl . data_from_values ( ... ) |&gt; Vl . concat ( [ Vl . new ( ) |&gt; ... , Vl . new ( ) |&gt; ... , Vl . new ( ) |&gt; ... ] ) Vl . new ( ) |&gt; Vl . data_from_values ( ... ) |&gt; Vl . concat ( [ Vl . new ( ) |&gt; ... , Vl . new ( ) |&gt; ... ] , :horizontal ) See the docs for more details.","ref":"VegaLite.html#concat/3","title":"VegaLite.concat/3","type":"function"},{"doc":"Adds view configuration to the specification. Configuration allows for setting general properties of the visualization. All provided options are converted to configuration properties and merged with the existing configuration in a shallow manner. Examples Vl . new ( ) |&gt; ... |&gt; Vl . config ( view : [ stroke : :transparent ] , padding : 100 , background : &quot;#333333&quot; ) See the docs for more details.","ref":"VegaLite.html#config/2","title":"VegaLite.config/2","type":"function"},{"doc":"Sets data properties in the specification. Defining the data source is usually the first step when building a graphic. For most use cases it's preferable to use more specific functions like data_from_url/3 or data_from_values/3 . All provided options are converted to data properties. Examples Vl . new ( ) |&gt; Vl . data ( sequence : [ start : 0 , stop : 12.7 , step : 0.1 , as : &quot;x&quot; ] ) |&gt; ... See the docs for more details.","ref":"VegaLite.html#data/2","title":"VegaLite.data/2","type":"function"},{"doc":"Sets data URL in the specification. The URL should be accessible by whichever client renders the specification, so preferably an absolute one. All provided options are converted to data properties. Examples Vl . new ( ) |&gt; Vl . data_from_url ( &quot;https://vega.github.io/editor/data/penguins.json&quot; ) |&gt; ... Vl . new ( ) |&gt; Vl . data_from_url ( &quot;https://vega.github.io/editor/data/stocks.csv&quot; , format : :csv ) |&gt; ... See the docs for more details.","ref":"VegaLite.html#data_from_url/3","title":"VegaLite.data_from_url/3","type":"function"},{"doc":"Sets inline data in the specification. Any tabular data is accepted, as long as it adheres to the Table.Reader protocol. Options :only - specifies a subset of fields to pick from the data All other options are converted to data properties. Examples data = [ %{ &quot;category&quot; =&gt; &quot;A&quot; , &quot;score&quot; =&gt; 28 } , %{ &quot;category&quot; =&gt; &quot;B&quot; , &quot;score&quot; =&gt; 55 } ] Vl . new ( ) |&gt; Vl . data_from_values ( data ) |&gt; ... Note that any tabular data is accepted, as long as it adheres to the Table.Reader protocol. For example that's how we can pass individual series: xs = 1 .. 100 ys = 1 .. 100 Vl . new ( ) |&gt; Vl . data_from_values ( x : xs , y : ys ) |&gt; ... See the docs for more details.","ref":"VegaLite.html#data_from_values/3","title":"VegaLite.data_from_values/3","type":"function"},{"doc":"Specifies top-level datasets. Datasets can be used as a data source further in the specification. This is useful if you need to refer to the data in multiple places or use a transform/2 like :lookup . Datasets should be a key-value enumerable, where key is the dataset name and value is tabular data as in data_from_values/3 . Examples results = [ %{ &quot;category&quot; =&gt; &quot;A&quot; , &quot;score&quot; =&gt; 28 } , %{ &quot;category&quot; =&gt; &quot;B&quot; , &quot;score&quot; =&gt; 55 } ] points = [ %{ &quot;x&quot; =&gt; &quot;1&quot; , &quot;y&quot; =&gt; 10 } , %{ &quot;x&quot; =&gt; &quot;2&quot; , &quot;y&quot; =&gt; 100 } ] Vl . new ( ) |&gt; Vl . datasets_from_values ( results : results , points : points ) # Use one of the data sets as the primary data |&gt; Vl . data ( name : &quot;results&quot; ) |&gt; ... See the docs for more details.","ref":"VegaLite.html#datasets_from_values/2","title":"VegaLite.datasets_from_values/2","type":"function"},{"doc":"Adds an encoding entry to the specification. Visual channel represents a property of a visual mark, for instance the :x and :y channels specify where a point should be placed. Encoding defines the source of values for those channels. In most cases you want to map specific data field to visual channels, prefer the encode_field/4 function for that. All provided options are converted to channel properties. Examples Vl . new ( ) |&gt; Vl . encode ( :x , value : 2 ) |&gt; ... Vl . new ( ) |&gt; Vl . encode ( :y , aggregate : :count , type : :quantitative ) |&gt; ... Vl . new ( ) |&gt; Vl . encode ( :y , field : &quot;price&quot; ) |&gt; ... Alternatively, a list of property lists may be given: Vl . new ( ) |&gt; Vl . encode ( :tooltip , [ [ field : &quot;height&quot; , type : :quantitative ] , [ field : &quot;width&quot; , type : :quantitative ] ] ) |&gt; ... See the docs for more details.","ref":"VegaLite.html#encode/3","title":"VegaLite.encode/3","type":"function"},{"doc":"Adds field encoding entry to the specification. A shorthand for encode/3 , mapping a data field to a visual channel. For example, if the data has &quot;price&quot; and &quot;time&quot; fields, you could map &quot;time&quot; to the :x channel and &quot;price&quot; to the :y channel. This, combined with a line mark, would then result in price-over-time plot. All provided options are converted to channel properties. Types Field data type is automatically inferred, but oftentimes needs to be specified explicitly to get the desired result. The :type option can be either of: :quantitative - when the field expresses some kind of quantity, typically numerical :temporal - when the field represents a point in time :nominal - when the field represents a category :ordinal - when the field represents a ranked order. It is similar to :nominal , but there is a clear order of values :geojson - when the field represents a geographic shape adhering to the GeoJSON specification See the docs for more details on types. Examples Vl . new ( ) |&gt; Vl . data_from_values ( ... ) |&gt; Vl . mark ( :point ) |&gt; Vl . encode_field ( :x , &quot;time&quot; , type : :temporal ) |&gt; Vl . encode_field ( :y , &quot;price&quot; , type : :quantitative ) |&gt; Vl . encode_field ( :color , &quot;country&quot; , type : :nominal ) |&gt; Vl . encode_field ( :size , &quot;count&quot; , type : :quantitative ) |&gt; ... Vl . new ( ) |&gt; Vl . encode_field ( :x , &quot;date&quot; , time_unit : :month , title : &quot;Month&quot; ) |&gt; Vl . encode_field ( :y , &quot;price&quot; , type : :quantitative , aggregate : :mean , title : &quot;Mean product price&quot; ) |&gt; ... See the docs for more details.","ref":"VegaLite.html#encode_field/4","title":"VegaLite.encode_field/4","type":"function"},{"doc":"Adds repeated field encoding entry to the specification. A shorthand for encode/3 , mapping a field to a visual channel, as given by the repeat operator. Repeat type must be either :repeat , :row , :column or :layer and correspond to the repeat definition. All provided options are converted to channel properties. Examples See repeat/3 to see the full picture. See the docs for more details.","ref":"VegaLite.html#encode_repeat/4","title":"VegaLite.encode_repeat/4","type":"function"},{"doc":"Builds a facet multi-view specification from the given single-view template. Facet definition must be either a field definition or a row/column mapping . Note that you can also create facet graphics by using the :facet , :column and :row encoding channels. Examples Vl . new ( ) |&gt; Vl . data_from_values ( ... ) |&gt; Vl . facet ( [ field : &quot;country&quot; ] , Vl . new ( ) |&gt; Vl . mark ( :bar ) |&gt; Vl . encode_field ( :x , ... ) |&gt; Vl . encode_field ( :y , ... ) ) Vl . new ( ) |&gt; Vl . data_from_values ( ... ) |&gt; Vl . facet ( [ row : [ field : &quot;country&quot; , title : &quot;Country&quot; ] , column : [ field : &quot;year&quot; , title : &quot;Year&quot; ] ] Vl . new ( ) |&gt; Vl . mark ( :bar ) |&gt; Vl . encode_field ( :x , ... ) |&gt; Vl . encode_field ( :y , ... ) ) See the docs for more details.","ref":"VegaLite.html#facet/3","title":"VegaLite.facet/3","type":"function"},{"doc":"Parses the given Vega-Lite JSON specification and wraps in the VegaLite struct for further processing. Examples Vl . from_json ( &quot;&quot;&quot; { &quot;data&quot;: { &quot;url&quot;: &quot;https://vega.github.io/editor/data/cars.json&quot; }, &quot;mark&quot;: &quot;point&quot;, &quot;encoding&quot;: { &quot;x&quot;: { &quot;field&quot;: &quot;Horsepower&quot;, &quot;type&quot;: &quot;quantitative&quot; }, &quot;y&quot;: { &quot;field&quot;: &quot;Miles_per_Gallon&quot;, &quot;type&quot;: &quot;quantitative&quot; } } } &quot;&quot;&quot; ) See the docs for more details.","ref":"VegaLite.html#from_json/1","title":"VegaLite.from_json/1","type":"function"},{"doc":"Wraps the given Vega-Lite specification in the VegaLite struct for further processing. There is also from_json/1 that handles JSON parsing for you. See the docs for more details.","ref":"VegaLite.html#from_spec/1","title":"VegaLite.from_spec/1","type":"function"},{"doc":"Builds a layered multi-view specification from the given list of single view specifications. Examples Vl . new ( ) |&gt; Vl . data_from_values ( ... ) |&gt; Vl . layers ( [ Vl . new ( ) |&gt; Vl . mark ( :line ) |&gt; Vl . encode_field ( :x , ... ) |&gt; Vl . encode_field ( :y , ... ) , Vl . new ( ) |&gt; Vl . mark ( :rule ) |&gt; Vl . encode_field ( :y , ... ) |&gt; Vl . encode ( :size , value : 2 ) ] ) Vl . new ( ) |&gt; Vl . data_from_values ( ... ) # Note: top-level data, encoding, transforms are inherited # by the child views unless overridden |&gt; Vl . encode_field ( :x , ... ) |&gt; Vl . layers ( [ ... ] ) See the docs for more details.","ref":"VegaLite.html#layers/2","title":"VegaLite.layers/2","type":"function"},{"doc":"Sets mark type in the specification. Mark is a predefined visual object like a point or a line. Visual properties of the mark are defined by encoding. All provided options are converted to mark properties. Examples Vl . new ( ) |&gt; Vl . mark ( :point ) |&gt; ... Vl . new ( ) |&gt; Vl . mark ( :point , tooltip : true ) |&gt; ... See the docs for more details.","ref":"VegaLite.html#mark/3","title":"VegaLite.mark/3","type":"function"},{"doc":"Returns a new specification wrapped in the VegaLite struct. All provided options are converted to top-level properties of the specification. Examples Vl . new ( title : &quot;My graph&quot; , width : 200 , height : 200 ) |&gt; ... See the docs for more details.","ref":"VegaLite.html#new/1","title":"VegaLite.new/1","type":"function"},{"doc":"Adds a parameter to the specification. Parameters are the basic building blocks for introducing interactions to graphics. All provided options are converted to parameter properties. Examples Vl . new ( ) |&gt; Vl . data_from_values ( ... ) |&gt; Vl . concat ( [ Vl . new ( ) # Define a parameter named &quot;brush&quot;, whose value is a user-selected interval on the x axis |&gt; Vl . param ( &quot;brush&quot; , select : [ type : :interval , encodings : [ :x ] ] ) |&gt; Vl . mark ( :area ) |&gt; Vl . encode_field ( :x , &quot;date&quot; , type : :temporal ) |&gt; ... , Vl . new ( ) |&gt; Vl . mark ( :area ) # Use the &quot;brush&quot; parameter value to limit the domain of this view |&gt; Vl . encode_field ( :x , &quot;date&quot; , type : :temporal , scale : [ domain : [ param : &quot;brush&quot; ] ] ) |&gt; ... ] ) See the docs for more details.","ref":"VegaLite.html#param/3","title":"VegaLite.param/3","type":"function"},{"doc":"Adds a projection spec to the specification. Projection maps longitude and latitude pairs to x, y coordinates. Examples Vl . new ( ) |&gt; Vl . data_from_values ( ... ) |&gt; Vl . projection ( type : :albers_usa ) |&gt; Vl . mark ( :circle ) |&gt; Vl . encode_field ( :longitude , &quot;longitude&quot; , type : :quantitative ) |&gt; Vl . encode_field ( :latitude , &quot;latitude&quot; , type : :quantitative ) See the docs for more details.","ref":"VegaLite.html#projection/2","title":"VegaLite.projection/2","type":"function"},{"doc":"Builds a repeated multi-view specification from the given single-view template. Repeat definition must be either a list of fields or a row/column/layer mapping . Then some channels can be bound to a repeated field using encode_repeat/4 . Examples # Simple repeat Vl . new ( ) |&gt; Vl . data_from_values ( ... ) |&gt; Vl . repeat ( [ &quot;temp_max&quot; , &quot;precipitation&quot; , &quot;wind&quot; ] , Vl . new ( ) |&gt; Vl . mark ( :line ) |&gt; Vl . encode_field ( :x , &quot;date&quot; , time_unit : :month ) # The graphic will be reapeated with :y mapped to &quot;temp_max&quot;, # &quot;precipitation&quot; and &quot;wind&quot; respectively |&gt; Vl . encode_repeat ( :y , :repeat , aggregate : :mean ) ) # Grid repeat Vl . new ( ) |&gt; Vl . data_from_values ( ... ) |&gt; Vl . repeat ( [ row : [ &quot;beak_length&quot; , &quot;beak_depth&quot; , &quot;flipper_length&quot; , &quot;body_mass&quot; ] , column : [ &quot;body_mass&quot; , &quot;flipper_length&quot; , &quot;beak_depth&quot; , &quot;beak_length&quot; ] ] , Vl . new ( ) |&gt; Vl . mark ( :point ) # The graphic will be repeated for every combination of :x and :y # taken from the :row and :column lists above |&gt; Vl . encode_repeat ( :x , :column , type : :quantitative ) |&gt; Vl . encode_repeat ( :y , :row , type : :quantitative ) ) See the docs for more details.","ref":"VegaLite.html#repeat/3","title":"VegaLite.repeat/3","type":"function"},{"doc":"Adds a resolve entry to the specification. Resolution defines how multi-view graphics are combined with regard to scales, axis and legend. Example Vl . new ( ) |&gt; Vl . data_from_values ( ... ) |&gt; Vl . layers ( [ Vl . new ( ) |&gt; ... , Vl . new ( ) |&gt; ... ] ) |&gt; Vl . resolve ( :scale , y : :independent ) See the docs for more details.","ref":"VegaLite.html#resolve/3","title":"VegaLite.resolve/3","type":"function"},{"doc":"Returns the underlying Vega-Lite specification. The result is a nested Elixir datastructure that serializes to Vega-Lite JSON specification. See the docs for more details.","ref":"VegaLite.html#to_spec/1","title":"VegaLite.to_spec/1","type":"function"},{"doc":"Adds a transformation to the specification. Transformation describes an operation on data, like calculating new fields, aggregating or filtering. All provided options are converted to transform properties. Examples Vl . new ( ) |&gt; Vl . data_from_values ( ... ) |&gt; Vl . transform ( calculate : &quot;sin(datum.x)&quot; , as : &quot;sin_x&quot; ) |&gt; ... Vl . new ( ) |&gt; Vl . data_from_values ( ... ) |&gt; Vl . transform ( filter : &quot;datum.height &gt; 150&quot; ) |&gt; ... Vl . new ( ) |&gt; Vl . data_from_values ( ... ) |&gt; Vl . transform ( regression : &quot;price&quot; , on : &quot;date&quot; ) |&gt; ... See the docs for more details.","ref":"VegaLite.html#transform/2","title":"VegaLite.transform/2","type":"function"},{"doc":"","ref":"VegaLite.html#t:spec/0","title":"VegaLite.spec/0","type":"type"},{"doc":"","ref":"VegaLite.html#t:t/0","title":"VegaLite.t/0","type":"type"},{"doc":"Various export methods for a VegaLite specification. All of the export functions depend on the :jason package. Additionally the PNG, SVG and PDF exports rely on npm packages, so you will need Node.js, npm , and the following dependencies: npm install - g vega vega - lite canvas # or in the current directory npm install vega vega - lite canvas","ref":"VegaLite.Export.html","title":"VegaLite.Export","type":"module"},{"doc":"","ref":"VegaLite.Export.html#run_cmd/2","title":"VegaLite.Export.run_cmd/2","type":"function"},{"doc":"Saves a VegaLite specification to file in one of the supported formats. Options :format - the format to export the graphic as, must be either of: :json , :html , :png , :svg , :pdf . By default the format is inferred from the file extension.","ref":"VegaLite.Export.html#save!/3","title":"VegaLite.Export.save!/3","type":"function"},{"doc":"Builds an HTML page that renders the given graphic. The HTML page loads necessary JavaScript dependencies from a CDN and then renders the graphic in a root element.","ref":"VegaLite.Export.html#to_html/1","title":"VegaLite.Export.to_html/1","type":"function"},{"doc":"Returns the underlying Vega-Lite specification as JSON.","ref":"VegaLite.Export.html#to_json/1","title":"VegaLite.Export.to_json/1","type":"function"},{"doc":"Renders the given graphic into a PDF and returns its binary content. Relies on the npm packages mentioned above.","ref":"VegaLite.Export.html#to_pdf/1","title":"VegaLite.Export.to_pdf/1","type":"function"},{"doc":"Renders the given graphic as a PNG image and returns its binary content. Relies on the npm packages mentioned above.","ref":"VegaLite.Export.html#to_png/1","title":"VegaLite.Export.to_png/1","type":"function"},{"doc":"Renders the given graphic as an SVG image and returns its binary content. Relies on the npm packages mentioned above.","ref":"VegaLite.Export.html#to_svg/1","title":"VegaLite.Export.to_svg/1","type":"function"},{"doc":"Graphics rendering using Erlang's :wx bindings. This method if useful for viewing graphics in scripts and IEx sessions. Note it requires Erlang/OTP 24+ with a recent WxWidgets installation with webview support.","ref":"VegaLite.Viewer.html","title":"VegaLite.Viewer","type":"module"},{"doc":"Renders a VegaLite specification in GUI window widget. Requires Erlang compilation to include the :wx module.","ref":"VegaLite.Viewer.html#show/1","title":"VegaLite.Viewer.show/1","type":"function"},{"doc":"Same as show/1 , but blocks until the window widget is closed.","ref":"VegaLite.Viewer.html#show_and_wait/1","title":"VegaLite.Viewer.show_and_wait/1","type":"function"}]